@@ -10,7 +10,7 @@ class ReportingClient(Client):
 
     def __init__(self, endpoint, token):
         super().__init__()
-        self.ENDPOINT = endpoint.rstrip("/")
+        self.ENDPOINT = endpoint
         self.token = token
 
     @property
@@ -18,57 +18,84 @@ class ReportingClient(Client):
         """The Reporting Service uses Digest Authentication."""
         return HttpAuth(self.token, key="X-RBX-TOKEN")
 
-    def create_schedule(self, body, campaign, cron, format, name, recipients, reports):
+    def create_schedule(
+        self,
+        body,
+        cron,
+        format,
+        name,
+        recipients,
+        reports,
+        campaign: int = None,
+        company: str = None,
+        timezone: str = "Etc/UTC",
+    ):
         """Create a scheduled job.
 
         Return the job_id of the job just created.
         """
         response = self._post(
-            "/schedule",
+            "schedule",
             data={
                 "body": body,
                 "campaign": campaign,
+                "company": company,
                 "cron": cron,
                 "format": format,
                 "name": name,
                 "recipients": recipients,
                 "reports": reports,
+                "timezone": timezone,
             },
         )
+
         return response.get("job_id")
 
     def delete_schedule(self, job_id):
         """Create the scheduled job."""
-        response = self._post("/schedule/delete", data={"job_id": job_id})
+        response = self._post("schedule/delete", data={"job_id": job_id})
         return response.get("job_id")
 
     def pause_schedule(self, job_id):
         """Pause the scheduled job."""
-        response = self._post("/schedule/pause", data={"job_id": job_id})
+        response = self._post("schedule/pause", data={"job_id": job_id})
         return response.get("job_id")
 
     def resume_schedule(self, job_id):
         """Resume the scheduled job."""
-        response = self._post("/schedule/resume", data={"job_id": job_id})
+        response = self._post("schedule/resume", data={"job_id": job_id})
         return response.get("job_id")
 
     def update_schedule(
-        self, body, campaign, cron, format, job_id, name, recipients, reports
+        self,
+        body,
+        cron,
+        format,
+        job_id,
+        name,
+        recipients,
+        reports,
+        campaign: int = None,
+        company: str = None,
+        timezone: str = "Etc/UTC",
     ):
         """Update the scheduled job."""
         response = self._post(
-            "/schedule",
+            "schedule",
             data={
                 "body": body,
                 "campaign": campaign,
+                "company": company,
                 "cron": cron,
                 "format": format,
                 "job_id": job_id,
                 "name": name,
                 "recipients": recipients,
                 "reports": reports,
+                "timezone": timezone,
             },
         )
+
         return response.get("job_id")
 
     def get_report(
@@ -169,4 +196,87 @@ class ReportingClient(Client):
             if label != "self" and value is not None:
                 data[label] = value
 
-        return self._post("/report", data=data)
+        return self._post("report", data=data)
+
+    def get_deal_facets(
+        self,
+        deals: [str],
+        date_range: str = None,
+        filters: [dict] = None,
+        timezone: str = None,
+        start_date: str = None,
+        end_date: str = None,
+    ) -> dict:
+        """Retrieve deal traffic facets using the specified parameters.
+
+        Parameters:
+
+            deal_ids (list[str]):
+                A list of deal ids to filter by.
+
+            date_range (string):
+                A standard relative dat range, in the form N{mhd}.
+                Where `N` is the number of minutes (`m`), hours (`h`), or days (`d`), until now.
+
+            filters (list[breakdown,operator,value]):
+                Filter results on the given Breakdown having the value matching the given operator.
+                Supported operators are: `eq`, `neq`, `in`, `nin`, and `like`
+
+            start_date (string):
+                The start date and time in ISO 8601 format.
+
+            end_date (string):
+                The end date and time in ISO 8601 format.
+
+            timezone (str):
+                The time zone name of the request,
+                If omitted, the time zone is assumed to be UTC.
+
+        Returns:
+            Dict.
+            A dict response containing the facets names and their values list.
+        """
+        kwargs = locals()
+        data = {}
+
+        for label, value in kwargs.items():
+            if label != "self" and value is not None:
+                data[label] = value
+
+        return self._post("/traffic/deals", data=data)
+
+    def get_traffic_facets(self, filters=None, date_range=None, timezone=None):
+        """Retrieve traffic facets using the specified parameters.
+
+        Parameters:
+
+            filters (list[breakdown,operator,value]):
+                Filter results on the given Breakdown having the value matching the given operator.
+                Supported operators are: `eq`, `neq`, `in`, `nin`, and `like`
+
+            date_range (string):
+                A standard relative dat range, in the form N{mhd}.
+                Where `N` is the number of minutes (`m`), hours (`h`), or days (`d`), until now.
+
+            start_date (string):
+                The start date and time in ISO 8601 format.
+
+            end_date (string):
+                The end date and time in ISO 8601 format.
+
+            timezone (str):
+                The time zone name of the request,
+                If omitted, the time zone is assumed to be UTC.
+
+        Returns:
+            Dict.
+            A dict response containing the facets names and their values list.
+        """
+        kwargs = locals()
+        data = {}
+
+        for label, value in kwargs.items():
+            if label != "self" and value is not None:
+                data[label] = value
+
+        return self._post("traffic/facets", data=data)
