@@ -10,6 +10,7 @@ This decorator will retry transient exceptions.
 >>> def call_method():
 >>>     return client.method()
 """
+
 import functools
 import logging
 import random
@@ -48,12 +49,16 @@ def if_exception_type(*exception_types):
 """A predicate that checks if an exception is a transient error.
 
 The following server errors are considered transient:
+- rbx.exceptions.RequestTimeout
+- rbx.exceptions.ServerError
+- rbx.exceptions.TooManyRequests
 - rbx.exceptions.TransientException
-- rbx.exceptions.TransientServerError
 """
 if_transient_error = if_exception_type(
+    exceptions.RequestTimeout,
+    exceptions.ServerError,
+    exceptions.TooManyRequests,
     exceptions.TransientException,
-    exceptions.TransientServerError,
 )
 
 
