@@ -72,12 +72,14 @@ class Forbidden(ClientException):
     status_code = 403
 
 
-class ServerError(ClientException):
-    """5xx server errors."""
+class RequestTimeout(ClientException):
+    message = "Request Timeout"
+    status_code = 408
 
 
-class TransientServerError(ClientException):
-    """Transient 5xx server errors."""
+class TooManyRequests(ClientException):
+    message = "Too Many Requests"
+    status_code = 429
 
 
 class Unauthorized(ClientException):
@@ -104,6 +106,10 @@ class RetryError(ClientException):
         return f"{self.message}, last exception: {self.cause}"
 
 
+class ServerError(HTTPException):
+    """5xx server errors."""
+
+
 class TransientException(Exception):
     """Raise this exception when we know the cause is transient (e.g.: connection errors,
     consistency error, ...).
